@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: vector-instances
 version: 3.3.1
-id: vector-instances-3.3.1-86a43cd9ce3eb5ed2f259da8231c727e
-key: vecto_79GP7i1Ksos9CDH9oIrUvc
+id: vector-instances-3.3.1-defbdcf4d1ffa7a1e6ebdf8243634c01
+key: vecto_ATBzJ1h6rApJ5wl3FzOLKo
 license: BSD3
 maintainer: ekmett@gmail.com
 homepage: http://github.com/ekmett/vector-instances
@@ -17,13 +17,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-instances-3.3.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-instances-3.3.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-instances-3.3.1
-hs-libraries: HSvector-instances-3.3.1-79GP7i1Ksos9CDH9oIrUvc
+hs-libraries: HSvector-instances-3.3.1-ATBzJ1h6rApJ5wl3FzOLKo
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    comonad-5-530ea4e1d08a0115920b946124e760ac
-    keys-3.11-2e2d252dcf362b6ae0acb007faf75b9e
-    pointed-5-1c4ea7ecb001f7c0b5b892b982c3648b
-    semigroupoids-5.0.1-fafa53fc1a76ec617ee4419105d11368
+    comonad-5-a91321d086a2de4a04a44d60c347669e
+    keys-3.11-138176c47b9b6dd0d393596bbcd2f16d
+    pointed-5-28a4d891bf88c5f993d8a907568960a6
+    semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
     semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
